@@ -1,7 +1,6 @@
 from .case import *
 
-from django.contrib.auth import get_user_model
-User = get_user_model()
+from django.contrib.auth.models import User
 
 
 class AutocompleteModelMock(autocomplete_light.AutocompleteModelBase):
